# AlertNow Python
This package used for logging information or errors.

#Installation
```pip install AlertNow-Python```

#How to use it?
First of all, you need to register with ```sign-up``` remote API and 
get the api key on the 
```https://alertnow-backend.herokuapp.com/api/swagger-ui.html```.
After, you must initialize connection using ```init``` method.
And you can use ```info``` or ```error``` methods.

